<template>
  <a-card
    :bordered="false"
    class="card-area"
  >
    <div class="ant-alert ant-alert-info" style="margin-bottom: 16px;">
      <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a style="font-weight: 600">{{ selectedRowKeys.length }}</a>项
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div>
    <a-table
      ref="table"
      bordered
      size="middle"
      rowKey="id"
      :columns="columns"
      :dataSource="dataSource"
      :pagination="ipagination"
      :loading="loading"
      :rowSelection="{selectedRowKeys: selectedRowKeys, onChange: onSelectChange}"
      @change="handleTableChange"
    >
    </a-table>
  </a-card>
  
</template>

<script>
import { requestPut } from '@/api/manage'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import JInput from '@/components/jeecg/JInput'
import JEllipsis from '@/components/jeecg/JEllipsis'
import { deleteAction, getAction, postAction } from '../../../../api/manage'

export default {
  name: 'BorrowUserRight',
  mixins: [JeecgListMixin],
  components: {
    JInput,
    JEllipsis,
  },
  props:{
    mainId:{
        type:String,
        default:'',
        required:false
    },
    userIdList:{
        type: String,
        default: '',
        required: false
    },
    enterpriseId:{
      type: String,
      default: '',
      required: false
    },
    departId:{
      type: String,
      default: '',
      required: false
    }
  },
  data() {
    return {
      //默认排序
      disableMixinCreated:true,
      editWarnhouseClientId:'',
      checkMessage:'',
      factoryType:0,
      preVisible:false,
      isorter: {
        column: 'num',
        order: 'asc',
      },
      dataSource:[],
      columns: [
           {
            title: '#',
            dataIndex: '',
            key:'rowIndex',
            align:"center",
            customRender:function (t,r,index) {
              return parseInt(index)+1;
            }
          },
          {
            title:'用户编码',
            align:"center",
            dataIndex: 'userName',
            width:170
          },
          {
            title:'用户姓名',
            align:"center",
            dataIndex: 'realName',
            width:170
          },
          {
            title:'所属部门',
            align:"center",
            dataIndex: 'departName',
            width:170
          },
      ],
      url: {
        list: "/base/workCenterUser/userList",
        check:"/base/warehouse/checkWarehouseClient"
      },
    };
  },
  methods: {
    myLoadData(parentId){
      console.log(parentId+'==='+this.enterpriseId)
      if(parentId==this.enterpriseId){
        this.queryParam["enterpriseId"] = this.enterpriseId;
        this.queryParam['userIdList'] = this.userIdList;
        this.queryParam['departId'] = this.departId;
        this.loadData(1);
      }
      else{
        this.queryParam['departId'] = parentId;
        this.queryParam['userIdList'] = this.userIdList;
        this.loadData(1);
      }
      this.clearQuery();
    },
    onSelectChange(selectedRowKeys, selectionRows) {
        this.selectedRowKeys = selectedRowKeys;
        this.selectionRows = selectionRows;
        this.$emit("getAddUserIds",selectedRowKeys);
    },
   clearSelectList(){
    this.selectedRowKeys=[];
   },
   clearQuery(){
    this.queryParam=[];
   },
  
   loadData(arg) {
      if(!this.url.list){
        this.$message.error("请设置url.list属性!")
        return
      }
      //加载数据 若传入参数1则加载第一页的内容
      if (arg === 1) {
        this.ipagination.current = 1;
      }
      var params = this.getQueryParams();//查询条件
      this.loading = true;
      getAction(this.url.list, params).then((res) => {
        if (res.success) {
          //update-begin---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
          this.dataSource = res.result.records||res.result;
          if(res.result.total)
          {
            this.ipagination.total = res.result.total;
          }else{
            this.ipagination.total = 0;
          }
          //update-end---author:zhangyafei    Date:20201118  for：适配不分页的数据列表------------
        }else{
          this.$message.warning(res.message)
        }
      }).finally(() => {
        this.loading = false
      })
    },
  },
  created(){
  },
}
</script>
<style>
@import '~@assets/less/common.less';

.frozenRowClass {
  color: #c9c9c9;
}
.success {
  color: green;
}
.error {
  color: red;
}
.fontweight {
  font-weight: bold;
}
.notShow{
  display: none
}
</style>